=====================
Abaqus Model Database
=====================

Mdb commands are used to create and upgrade an Abaqus model database that stores models and analysis controls.


.. toctree::
   :maxdepth: 1
   :caption: Objects in Mdb
   
   mdb/model
   mdb/job
   mdb/annotation
   mdb/edit_mesh


Classes
-------

Mdb
~~~

.. autoclass:: abaqus.Mdb.Mdb.Mdb
   :members:
   :special-members: __init__

   .. autoclasstoc::

MdbBase
~~~~~~~

.. autoclass:: abaqus.Mdb.MdbBase.MdbBase
   :members:
   :special-members: __init__

   .. autoclasstoc::

AcisMdb
~~~~~~~

.. autoclass:: abaqus.Part.AcisMdb.AcisMdb
   :members:
   :special-members: __init__

   .. autoclasstoc::

JobMdb
~~~~~~

.. autoclass:: abaqus.Job.JobMdb.JobMdb
   :members:
   :special-members: __init__

   .. autoclasstoc::
